@@ -1,7 +1,7 @@
 /*
  * proccpuinfo.h - public interface for libproccpuinfo
  *
- * Copyright (C) 2006, 2007, 2008 Thomas Cort <tom@tomcort.com>
+ * Copyright (C) 2006, 2007, 2008, 2009 Thomas Cort <tcort@tomcort.com>
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,7 +20,7 @@
 #ifndef __PROCCPUINFO_H
 #define __PROCCPUINFO_H
 
-typedef struct proccpuinfo {;
+typedef struct proccpuinfo {
 	unsigned short version;
 	char *architecture;
 	char *hardware_platform;
